# /**
#
# \name{interweave}
#
# \title{interweave}
#
# \alias{interweave}
#
# \keyword{}
#
# \description{ very unimportant ...
#                 \code{AsIs} class objects A or B are coerced to a vector }
#
# \value{}
#
#
# \arguments{
#  \item{A}{vectors, matrices, one- and two-dimensional arrays;
#                an  \code{AsIs} class object is coerced to a vector }
#  \item{B}{vectors, matrices, one- and two-dimensional arrays;
#                an  \code{AsIs} class object is coerced to a vector }
# }
# 
# \details{}
#
# \seealso{\code{\link{}}}
#
# \examples{
#    x <- seq(1,100,2)
#    y <- seq(2,100,2)
#    z <- interweave(x,y)
#    stopifnot( all.equal(z,1:100) )
#	}
#
# \keyword{}
#
# \author{Andreas Buness <a.buness@dkfz.de>}
# */
interweave <- function( A, B){

  if( ! is.null(class(A)) ){
    if( class(A) == "AsIs" ){
      A <- as.vector(A)
    }
  }
  if( ! (is.vector(A) | is.matrix(A) | is.array(A)) ){
    stop(" A of wrong type in interweave \n")
  }
  if( ! is.null(class(B)) ){
    if( class(B) == "AsIs" ){
      B <- as.vector(B)
    }
    if( ! (is.vector(B) | is.matrix(B) | is.array(B)) ){
      stop(" B of wrong type in interweave \n")
    }
  }
  
  if(( is.vector(A) & is.vector(B) ) |
     ( is.array(A) & length(dim(A))==1 &
      is.array(B) & length(dim(B))==1   )){
    VECTOR <- TRUE
    A <- t(as.matrix(A))
    B <- t(as.matrix(B))
  }else{
    VECTOR <- FALSE
  }
  
    # note: two-dimensional arrays are matrices
  stopifnot( is.matrix(A) )
  stopifnot( is.matrix(B) )
    
  stopifnot( ncol(A) == ncol(B) )
  l <- ncol(A)
  generatePairs <- function(x,l){
    return(c(x,x+l))
  }
  indexes <- as.vector(sapply(1:l,function(x) generatePairs(x,l)))
  stopifnot( all(sort(indexes) == 1:(2*l)) )
  if( VECTOR ){
    return( as.vector(cbind(A,B)[,indexes]) )
  }else{
    return( cbind(A,B)[,indexes] )
  }
}
