# TO DO testing

# /**
#
# \name{setZeroWeights}
#
# \title{setZeroWeights}
#
# \alias{setZeroWeights}
#
# \keyword{}
#
# \description{}
#
# \value{object of class \code{arrayData}}
#
#
# \arguments{
#  \item{arrayDataObject}{object of class \code{arrayData}}
#  \item{spotsWithZeroWeights}{vector of character strings}
#  \item{spotIdentifier}{character string}
# }
# 
# \details{}
#
# \seealso{\code{\link{}}}
#
# \examples{
#	}
#
# \keyword{}
#
# \author{Andreas Buness <a.buness@dkfz.de>}
# */
setZeroWeights <- function(arrayDataObject, spotsWithZeroWeights, spotIdentifier){

  if( missing(arrayDataObject) ){
    cat(" no arrayDataObject in setZeroWeights\n")
    return()
  }
  if( missing(spotIdentifier) ){
    cat(" no spotIdentifier in setZeroWeights\n")
    return()
  }
  if( class(arrayDataObject) != "arrayData" ){
    cat(" class(arrayDataObject) != \"arrayData\" in setZeroWeights\n")
    return()
  }
  if( length(spotIdentifier) != 1 ){
    cat(" length(spotIdentifier) != 1 in setZeroWeights\n")
    return()
  }
  if( missing(spotsWithZeroWeights) ){
    cat(" no spotsWithZeroWeights in setZeroWeights\n")
    return(arrayDataObject)
  }
  if( length(spotsWithZeroWeights) < 1 ){
    cat(" length(spotsWithZeroWeights) < 1 in setZeroWeights\n")
    return(arrayDataObject)
  }

  spotattr <- getSpotAttr(arrayDataObject)
  intensities <- getIntensities(arrayDataObject)
  hybattr <- getHybAttr(arrayDataObject)
  weights <- getWeights(arrayDataObject)
  
  if( is.null(spotattr) ){
    warning(" getSpotAttr(arrayDataObject) is NULL in setZeroWeights  ")
    return(arrayDataObject)
  }
  if( length(spotattr) < 1 ){
    warning(" getSpotAttr(arrayDataObject) has length < 1 in setZeroWeights ")
    return(arrayDataObject)
  }

  if( ! (spotIdentifier %in% colnames(spotattr)) ){
    warning(" no appropriate column in getSpotAttr(arrayDataObject) in setZeroWeights")
    return(arrayDataObject)
  }

  if( is.null(intensities) ){
    warning(" getIntensities(arrayDataObject) is NULL in setZeroWeights  ")
    return(arrayDataObject)
  }
  if( length(intensities) < 1 ){
    warning(" getIntensities(arrayDataObject) has length < 1 in setZeroWeights ")
    return(arrayDataObject)
  }

  # create weights, by default all weights are set one
  if( length(weights) < 1){
    weights <- matrix(data=1, nrow=dim(intensities)[1], ncol=dim(intensities)[3])
  }

  # set particular weights to zero
  zeroItems <- sapply(spotsWithZeroWeights, function(x) return(which( spotattr[,spotIdentifier] == x)), simplify=TRUE )
  zeroItems <- na.exclude(as.numeric(unlist(zeroItems)))
  nrOfZeroItems <- length(zeroItems)
  if( nrOfZeroItems == 0 ){
    # nothing to do
    weights <- weights
  }else{
    weights[zeroItems,] <- 0
  }
  
  return(new("arrayData", intensities=intensities, weights=weights, spotattr=spotattr, hybattr=hybattr))
  


}#end of setZeroWeights
