# TO DO
# ungeloestes Problem rbind kreiert Faktoren !!
# more testing
#
#

# /**
#
# \name{slideMerge}
#
# \title{slideMerge}
#
# \alias{slideMerge}
#
# \keyword{}
#
# \description{}
#
# \value{modified \code{exprSetArrayObject}}
#
#
# \arguments{
#  \item{exprSetArrayObject}{object of class exprSetArray}
#  \item{slideMergeVariable}{ character string specifying the variable of the \code{phenoData} used to determine replicas}
#  \item{sampleAnnotationColumns}{ vector of character strings;
#      containing all phenoData variables relevant for further analysis.
#      The annotation should be consistent for replicas.
#      By default all phenoData variables are taken, i.e.
#      sampleAnnotationColumns is missing.}
#
# }
# 
# \details{}
#
# \seealso{\code{\link{spotMerge}}}
#
# \examples{
#
#  indCy3=1:4
#  indCy5=5:8
#  channels <- matrix( c(indCy3,indCy5), nrow=length(indCy3), byrow=FALSE )
#  colnames(channels) <- c("Cy3","Cy5")
#  myMatrix <- matrix(c(1:8,rep(1:4,2),c(1,1,1,4,2,2,2,2),c(2,2,2,2,4,1,1,1) ,rep(c(1,1,2,2),2)),nrow=8,ncol=5,byrow=FALSE)
#  colnames(myMatrix) <- c("one","two","three","four","merge")
#  exprsMatrix <-  matrix(rep(1:10,4), ncol=8, nrow=5, byrow=FALSE) 
#  eSA <- new("exprSetArray", exprs=exprsMatrix, phenoData=
#                new("phenoData", pData=data.frame(myMatrix),
#                varLabels=as.list(colnames(myMatrix))),
#              channels=channels)
#  eSM <- slideMerge(exprSetArrayObject=eSA, slideMergeVariable="merge")
#  stopifnot( all(  dim(exprs(eSM)) == c(5,4) ) )
#  stopifnot( all(as.matrix(pData((phenoDataSlide(eSM)[,which(varLabels(phenoDataSlide(eSM)) == "slidesInGroup")]))) == matrix(c("1;2","3;4"),ncol=1,nrow=2)) )
#	  exprs(eSM)
#  stopifnot( all(exprs(getExprSetCy3(eSM)) == cbind(rowMeans(exprs(getExprSetCy3(eSA))[,1:2]), rowMeans(exprs(getExprSetCy3(eSA))[,3:4]))))
#  stopifnot( all(exprs(getExprSetCy5(eSM)) == cbind(rowMeans(exprs(getExprSetCy5(eSA))[,1:2]), rowMeans(exprs(getExprSetCy5(eSA))[,3:4]))))
#  stopifnot(se.exprs(getExprSetCy3(eSM)) == cbind(as.matrix(apply((exprs(getExprSetCy3(eSA))[,1:2]),1,sd)), as.matrix(apply((exprs(getExprSetCy3(eSA))[,3:4]),1,sd))))
#  stopifnot(se.exprs(getExprSetCy5(eSM)) == cbind(as.matrix(apply((exprs(getExprSetCy5(eSA))[,1:2]),1,sd)), as.matrix(apply((exprs(getExprSetCy5(eSA))[,3:4]),1,sd))))
#  # one and two are inconsistent in both channels
#  stopifnot( all(unlist(varLabels(phenoDataSlide(eSM))) == c("one","two","merge","slidesInGroup")) )
#
#
#	}
#
# \keyword{}
#
# \author{Andreas Buness <a.buness@dkfz.de>}
# */

slideMerge <- function(exprSetArrayObject, slideMergeVariable, sampleAnnotationColumns){

  if( missing(exprSetArrayObject) ){
    cat(" no exprSetArrayObject in slideMerge ")
    return()
  }
  if( missing(slideMergeVariable) ){
    cat(" no slideMergeVariable in slideMerge ")
    return()
  }

  if( ! slideMergeVariable %in% varLabels(phenoDataSlide(exprSetArrayObject)) ){
    cat(" slideMergeVariable not given in varLabels(phenoDataSlide) in slideMerge ")
    return()
  }
  
  cat("\n\n merging of slides \n")
  
  phenoSlide <-  phenoDataSlide(exprSetArrayObject)
  slideGroups <- as.vector(as.matrix(pData(phenoSlide[,which(varLabels(phenoSlide) == slideMergeVariable)])))
  
  phenoCy3 <- phenoDataCy3(exprSetArrayObject)
  phenoCy5 <- phenoDataCy5(exprSetArrayObject)
  
  if( ! missing(sampleAnnotationColumns) ){
    if( ! all(sampleAnnotationColumns %in% varLabels(phenoSlide)) ){
      cat(" sampleAnnotationColumns not given in varLabels(phenoDataSlide) in slideMerge ")
      return()
    }
    phenoCy3 <- phenoCy3[,which(varLabels(phenoCy3) %in% sampleAnnotationColumns)]
    phenoCy5 <- phenoCy5[,which(varLabels(phenoCy5) %in% sampleAnnotationColumns)]
    
  }

  phenoCy3Reduced <- phenoCy3[!duplicated(slideGroups),]
  phenoCy5Reduced <- phenoCy5[!duplicated(slideGroups),]
  
    
  cat(" number of replicas for each group\n")
  tmpTable <- table(as.factor(slideGroups))
  cat(" group names:\n")
  cat(cat(names(tmpTable)));cat("\n")
  cat(" number of replicas:\n")
  cat(tmpTable);cat("\n")
  
  uniqueGroups <- unique(slideGroups)

  exprsDataCy3 <-  exprs(getExprSetCy3(exprSetArrayObject))
  tmpExprsDataCy3 <- array(0, dim=c(nrow(exprsDataCy3), length(uniqueGroups)))
  sdMergeCy3 <- tmpExprsDataCy3
  
  exprsDataCy5 <-  exprs(getExprSetCy5(exprSetArrayObject))
  tmpExprsDataCy5 <- array(0, dim=c(nrow(exprsDataCy5), length(uniqueGroups)))
  sdMergeCy5 <- tmpExprsDataCy5
 
  slidesInGroup <- vector(mode="character",length=length(uniqueGroups))

  for(i in 1:length(uniqueGroups)){
    
    tmpGroup <- uniqueGroups[i]
    slidesInGroup[i] <- paste(which(slideGroups==tmpGroup), collapse=";")

    tmpExprsDataCy3[,i] <- apply(exprsDataCy3[,which(slideGroups==tmpGroup),drop=FALSE],1,mean)
    sdMergeCy3[,i] <- apply(exprsDataCy3[,which(slideGroups==tmpGroup),drop=FALSE],1,sd)
    tmpExprsDataCy5[,i] <- apply(exprsDataCy5[,which(slideGroups==tmpGroup),drop=FALSE],1,mean)
    sdMergeCy5[,i] <- apply(exprsDataCy5[,which(slideGroups==tmpGroup),drop=FALSE],1,sd)

  }


  consistencyCheck <- function(phenoDataObj, slideGroups, slideMergeVariable){
    
    inconsistentVariables <- vector(mode="character", length=0)
    varLabelsList <- varLabels(phenoDataObj)
    
    for( i in varLabelsList ){
      if( i != slideMergeVariable ){
        if( ! all(unlist(lapply(as.list(unique(slideGroups)), function(x) return( length(unique(as.vector(as.matrix(pData(phenoDataObj[ as.vector(as.matrix(pData(phenoDataObj[,which( varLabels(phenoDataObj) == slideMergeVariable)]))) == x, which( varLabels(phenoDataObj) == i )]))))) == 1))))){
          cat(" merging inconsistency for phenoData/annotation variable: ",i,"\n")
          inconsistentVariables <- append(inconsistentVariables, i)
        }
      }
    }# end of for i

    return(inconsistentVariables)
    
  }# end of consistencyCheck

  INCONSISTENCYTEXT <- "merging inconsistency wrt"
  cat("\n checking merging consistency of phenoDataCy3 \n") 
  inconsistentInCy3 <- consistencyCheck(phenoDataObj=phenoCy3, slideGroups=slideGroups, slideMergeVariable=slideMergeVariable)
  for(i in which( varLabels(phenoCy3Reduced) %in% inconsistentInCy3)){
    phenoCy3Reduced[[i]] <- paste(INCONSISTENCYTEXT,slideMergeVariable, sep=" ")
  }

  cat("\n checking merging consistency of phenoDataCy5 \n") 
  inconsistentInCy5 <- consistencyCheck(phenoDataObj=phenoCy5, slideGroups=slideGroups, slideMergeVariable=slideMergeVariable)
  for(i in which( varLabels(phenoCy5Reduced) %in% inconsistentInCy5)){
    phenoCy5Reduced[[i]] <- paste(INCONSISTENCYTEXT,slideMergeVariable, sep=" ") 
  }
  
  exprsData <- as.matrix(cbind( tmpExprsDataCy3, tmpExprsDataCy5 ) )
  sdMergeSlide <- as.matrix(cbind(sdMergeCy3, sdMergeCy5))
  notes <- paste(notes(exprSetArrayObject)," and se.exprs is based on the standard deviation of the slide merge operation")

  stopifnot( all(unlist(varLabels(phenoCy5Reduced)) == unlist(varLabels(phenoCy3Reduced))) )
  varLabelsList <- append(varLabels(phenoCy3Reduced), "slidesInGroup" )
  
  pDataObj <- rbind(cbind(pData(phenoCy3Reduced),I(slidesInGroup)),cbind(pData(phenoCy5Reduced),I(slidesInGroup)))
  colnames(pDataObj) <- unlist(varLabelsList)
  phenoDataObj <- new("phenoData", pData=pDataObj, varLabels=varLabelsList)


  indCy3 <- 1:ncol(tmpExprsDataCy3)
  indCy5 <- (ncol(tmpExprsDataCy3)+1):(ncol(tmpExprsDataCy3)+ncol(tmpExprsDataCy5))

  channels <- matrix( c(indCy3,indCy5), nrow=length(indCy3), byrow=FALSE )
  colnames(channels) <- c("Cy3","Cy5")

  newObject <- new("exprSetArray",
                   exprs=exprsData,
                   se.exprs=sdMergeSlide,
                   notes=notes,
                   phenoData=phenoDataObj,
                   channels=channels)

  return(newObject)

  
}
