# /**
#
# \name{spatialLayout}
#
# \title{spatialLayout}
#
# \alias{spatialLayout}
#
# \keyword{}
#
# \description{All values are mapped on a matrix representing the
#              the spatial layout defined by \code{row}, \code{column}
#              and \code{block}.}
#
# \value{A matrix representing the spatial layout of all values.}
#
#
# \arguments{
#  \item{value}{numeric vector}
#  \item{row}{integer vector}
#  \item{col}{integer vector}
#  \item{block}{integer vector}
#  \item{nrOfBlocksPerRow}{integer; default 4}
#  \item{mapping}{integer; either zero or one; default zero
#                 which corresponds to "ScanAlyze"; cf. source code}
# }
# 
# \details{}
#
# \seealso{\code{\link{}}}
#
# \examples{
#	}
#
# \keyword{}
#
# \author{Andreas Buness <a.buness@dkfz.de>}
# */


spatialLayout <- function (value, row, col, block, nrOfBlocksPerRow = 4,
                           mapping = 0) 
{
    stopifnot(length(row) == length(col))
    stopifnot(length(col) == length(value))
    stopifnot(length(value) == length(block))

    nrRow <- max(row)
    nrCol <- max(col)

    mat <- matrix(rep(as.numeric(NA), length(row)),
                  ncol = (nrCol * nrOfBlocksPerRow))

    if( mapping == 0 ){
      i <- nrRow * ((block - 1)%/%nrOfBlocksPerRow) + row
      j <- nrCol * ((block - 1)%%nrOfBlocksPerRow) + col
    }else if( mapping == 1 ){
      i <- nrRow * ((block - 1)%%nrOfBlocksPerRow) + row
      j <- nrCol * ((block - 1)%/%nrOfBlocksPerRow) + col
    }else{
      stop("unknown mapping in spatialLayout")
    }
      
    stopifnot(all(unique(sort(i)) == (1:(nrRow * nrOfBlocksPerRow))))
    stopifnot(all(unique(sort(j)) == (1:(nrCol * nrOfBlocksPerRow))))

    dummy <- apply(cbind(i, j, value), 1, function(z) mat[z[1], z[2]] <<- z[3])

    return(mat)

  }
