\name{exprSetArray-class}
\docType{class}
\alias{exprSetArray}
\alias{exprSetArray-class}
\title{Class exprSetArray, an extension for cDNA data of the class exprSet, which a class for microarray data, and methods for  processing them } 
\description{ This is class representation for cDNA Microarray Data}

\section{Creating Objects}{
\code{  new('exprSetArray',}\cr
\code{    channels = ..., # Object of class matrix with columns "Cy3"
  and "Cy5" }\cr
\code{    exprs    = ..., # Object of class matrix}\cr
\code{    se.exprs = ..., # Object of class matrix}\cr
\code{    phenoData= ..., # Object of class phenoData}\cr
\code{    notes    = ...., # Object of class character}\cr
\code{  )}}
\section{Slots}{
  \describe{
    \item{\code{indCy3}:}{Object of class "vector"; indexes of channel Cy3}
    \item{\code{indCy5}:}{Object of class "vector"; indexes of channel Cy5}
    \item{\code{exprs}:}{Object of class "matrix"; the observed
      expression levels. This is a matrix with columns representing
      channels Cy3 and Cy5, the pairs given in \code{channels} define
      slides and rows representing genes. }
    \item{\code{se.exprs}:}{Object of class "matrix"; this is
     a matrix of the same dimensions as \code{exprs} which contains
     standard error estimates for the estimated expression levels. }
    \item{\code{phenoData}:}{Object of class "phenoData" This is an
      instance of class \code{phenoData} 
    containing channel annotations. The columns of the
    pData slot of this entity represent
    variables and the rows represent channels. }
    \item{\code{notes}:}{Object of class "character" Vector of
      explanatory text }
  }
}

\section{Methods}{
  \describe{

    \item{show}{(exprSetArray): renders information about the exprSetArray
      in a concise way on stdout, cf. exprSet }
    
    \item{getExprSetDiff}{(exprSetArray): Returns an \code{exprSet}
      object of the difference of the expression levels of channel Cy3
      and channel Cy5. The se.exprs slot contains the sum of the
      se.exprs of both channels.
    }

    \item{getExprSetCy3MinusCy5}{ same as \code{getExprSetDiff} }
    
    \item{getExprSetCy3}{(exprSetArray): Returns an \code{exprSet}
      object of the expression levels of channel Cy3}
    
    \item{getExprSetCy5}{(exprSetArray): Returns an \code{exprSet}
      object of the expression levels of channel Cy5}

    \item{phenoDataSlide}{(exprSetArray): Returns an \code{phenoData}
      object of the slides which contains those annotation
      information (variables), which are the same for both channels,
      e.g. the slide number - NAs are not taken into consideration.}
      
    \item{pDataSlide}{(exprSetArray): Returns an \code{pData}
      object of the slides which contains those annotation
      information (variables), which is the same for both channels,
      e.g. the slide number - NAs are not taken into consideration.
      Do not use varLabels-names for subsetting - only indexes.}

    \item{phenoDataCy3}{(exprSetArray): Returns an \code{phenoData}
      object of the annotation information given for channel Cy3.
      Do not use varLabels-names for subsetting - only indexes.}
      
    \item{pDataCy3}{(exprSetArray): Returns the \code{pData}
      object given by \code{phenoDataCy3}.
      Do not use varLabels-names for subsetting - only indexes.}

    \item{phenoDataCy5}{(exprSetArray): Returns an \code{phenoData}
      object of the annotation information given for channel Cy5.
      Do not use varLabels-names for subsetting - only indexes.}
      
    \item{pDataCy5}{(exprSetArray): Returns the \code{pData}
      object given by \code{phenoDataCy5}.
      Do not use varLabels-names for subsetting - only indexes.}

    \item{slideSubset}{(exprSetArray,i,j): Subsetting; i corresponds to
      the rows  and j corresponds to the slides.
      j is given by indexes or logicals related to the order
      of the channel pairs; cf. the constructor slot \code{channels}}
    
    \item{getIndCy3}{(exprSetArray): An accessor function for slot
      \code{indCy3}. The matching pairs of indCy3 and indCy5 define slides.}

    \item{getIndCy5}{(exprSetArray): An accessor function for slot
      \code{indCy5}. The matching pairs of indCy3 and indCy5 define slides.}
    
    \item{[}{(exprSetArray,i,j,type):
      A subset operator.
      Ensures that both \code{exprs}
      and \code{phenoData} are subseted properly; but
      may mix up the pairing of the channels,
      i.e. the validity of an exprSetArray,
      if you use type == "invalidExprSetArray"}

    \item{concatenateExprSetArrays}{(objectOne,objectTwo): Concatenates
      two \code{exprSetArray} objects. Genes/rows are assumed to match;
      identical \code{varLabels} are required.}

    \item{exprSet}{(exprSetArray): Class cast, returns an object of
      \code{exprSet}, the channel information is dicarded.}
    
    } 
  }
}
\examples{}
\seealso{exprSet-class,exprSet}
\keyword{methods}
