%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This file was automatically generated by Rdoc on 2003-09-26 13:36:30.
% Do NOT modify this file, instead modify the source (/net/herkules/raid6/home/buness/R/Rpacks/arrayMagicCore/arrayMagic/R/qualityParameters.R).
% Rdoc is copyright (C) 2001, Henrik Bengtsson, henrikb@braju.com.
% Download the Rdoc compiler at http://www.braju.com/R/
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


 \name{qualityParameters}

 \title{Calculation of quality characteristics for cDNA chip hybridisations}

 \alias{qualityParameters}

 \keyword{}

 \description{ } 

 \usage{ }


 \value{returns a list of results, i.e. a data frame \code{qualityParameters} containing
   several scores for each hybridisation, a matrix \code{slideDistance} and
   an integer \code{replicateSpots}, i.e. the number of spot replicates.
 
   The matrix \code{slideDistance} contains a distance measure (similarity) for each pair
   of slides$_{ij}$, i.e. the median absolute deviation taken over all spots of the
   difference of the "log-ratios" ("log-ratios": the difference of the expression values
   in the two channels on the slide).

   A brief summary of all parameters given the data frame \code{qualityParameters}:
   \code{width}
   a robust measure of the variance, i.e. the median absolute deviation
   of the difference of the normalised channels taken over all spots

   \code{medianDistance}
   a robust measure for the typical distance (similarity) of one slide
   with all other slides, i.e. the median of the "distances"
   between slides (c.f. \code{slideDistance}))

   \code{correlation}
   of the expression values between the two channels of the slide taken over all spots

   \code{meanIntensityCy3}
   the mean taken over all spots of raw data channel Cy3

   \code{meanIntensityCy5}
   the mean taken over all spots of raw data channel Cy5

   \code{meanIntensity}
   mean taken over all spots of raw data of both channels,

   \code{spotSimilarityCy3}
   the standard deviation of all spot replicates for each unique identifier
   of the normalised channel Cy3 is calculated and the
   median standard deviation
   is taken as spotSimilarityCy3; if duplicate spots have been detected, i.e.
   \code{replicateSpots == 2}, the correlation is calculated instead

   \code{spotSimilarityCy3}
   the standard deviation of all spot replicates for each unique identifier
   of the normalised channel Cy3 is calculated and the
   median standard deviation
   is taken as spotSimilarityCy3; if duplicate spots have been detected, i.e.
   \code{replicateSpots == 2}, the correlation is calculated instead

   \code{cy3vsAllCy3} and \code{cy5vsAllCy5}
   the correlation between each channel is measured against the
   averaged (median) channel over all hybridisations
   (e.g. a virtual reference)
 }


 \arguments{
  \item{arrayDataObject}{object of type \code{arrayData}; default: missing}
  \item{exprSetArrayObject}{object of type \code{exprSetArray}; default: missing}
  \item{spotIdentifier}{ character string, column name used in getSpotAttr(arrayDataObject);
                         the column is used to determine spot replicas;
                         default: "Name"}
  \item{hybNameColumn}{ character string, column name used in getHybAttr(arrayDataObject);
                        the column is used to extract the names of the hybridisations;
                        if not available the order is taken instead;
                        default:  "slideNumber"}
  \item{identifiersToBeSkipped}{vector of character strings of spot identifiers
                                to be excluded from calculations}
  \item{resultFileName}{character string; results are stored in a file if supplied;
                        default: missing}
  \item{verbose}{logical; default \code{TRUE}}
 }
 
 \details{}

 \seealso{\code{}}

  \examples{
      spotIdentifierVec <- c("A","A","Blank","B","B","Blank")
      hybNames <- "H1"
      R1 <- N1 <- c(1,1,9,2,2,10)
      R2 <- N2 <- c(2,2,7,4,4,8)
      rawDataIntensities <- array(0, dim=c(6,2,1))
      rawDataIntensities[,1,] <- R1
      rawDataIntensities[,2,] <- R2
      dimnames(rawDataIntensities) <- list(NULL, c("Cy3","Cy5"), NULL)
      spotattr=data.frame(Name=I(spotIdentifierVec))
      hybattr=data.frame(slideNumber=I(hybNames))
      arrayDataObject <- new("arrayData", intensities=rawDataIntensities, hybattr=hybattr, spotattr=spotattr)
      indCy3=1
      indCy5=2
      channels <- matrix( c(indCy3,indCy5), nrow=length(indCy3), byrow=FALSE )
      colnames(channels) <- c("Cy3","Cy5")
      exprSetArrayObject <- new("exprSetArray", 	
	exprs=matrix(c(R1,R2), nrow=6, byrow=FALSE), phenoData=	
          new("phenoData", pData=data.frame(matrix(0,nrow=2,ncol=1)),
              varLabels=list(rep("varLabel1",1))), channels=channels)		
      Re1 <- qualityParameters(arrayDataObject=arrayDataObject, exprSetArrayObject=exprSetArrayObject, identifiersToBeSkipped= "Blank")
      stopifnot(all.equal.numeric(as.numeric(Re1$qualityParameters["H1",c("correlation")]),c(1)))
      stopifnot(Re1$replicateSpots==2)
   \testonly{
      spotIdentifierVec <- c("Blank","A","A","A","B","B","B")
      R1 <- N1 <- c(10,1,1,1,2,2,2)
      R2 <- N2 <- c(11,2,2,2,4,4,4)
      rawDataIntensities <- array(0, dim=c(7,2,1))
      rawDataIntensities[,1,] <- R1
      rawDataIntensities[,2,] <- R2
      dimnames(rawDataIntensities) <- list(NULL, c("Cy3","Cy5"), NULL)
      spotattr=data.frame(Name=I(spotIdentifierVec))
      hybattr=data.frame(slideNumber=I(hybNames))
      arrayDataObject <- new("arrayData", intensities=rawDataIntensities, hybattr=hybattr, spotattr=spotattr)
      indCy3=1
      indCy5=2
      channels <- matrix( c(indCy3,indCy5), nrow=length(indCy3), byrow=FALSE )
      colnames(channels) <- c("Cy3","Cy5")
      exprSetArrayObject <- new("exprSetArray", 	
	exprs=matrix(c(R1,R2), nrow=7, byrow=FALSE), phenoData=	
          new("phenoData", pData=data.frame(matrix(0,nrow=2,ncol=1)),
              varLabels=list(rep("varLabel1",1))), channels=channels)		


      Re2 <- qualityParameters(arrayDataObject=arrayDataObject, exprSetArrayObject=exprSetArrayObject, identifiersToBeSkipped= "Blank")

      stopifnot(all.equal.numeric(as.numeric(Re2$qualityParameters["H1",c("correlation")]),c(1)))
      stopifnot(Re2$replicateSpots==3)

      hybNames <- c("H1","H2")
      Xr1 <- Xn1 <- cbind(R1,R2)
      Xr2 <- Xn2 <- cbind(R2,R1)
      rawDataIntensities <- array(0, dim=c(7,2,2))
      rawDataIntensities[,1,1:2] <- Xr1
      rawDataIntensities[,2,1:2] <- Xr2
      dimnames(rawDataIntensities) <- list(NULL, c("Cy3","Cy5"), NULL)
      spotattr=data.frame(Name=I(spotIdentifierVec))
      hybattr=data.frame(slideNumber=I(hybNames))
      arrayDataObject <- new("arrayData", intensities=rawDataIntensities, hybattr=hybattr, spotattr=spotattr)
      indCy3=1:2
      indCy5=3:4
      channels <- matrix( c(indCy3,indCy5), nrow=length(indCy3), byrow=FALSE )
      colnames(channels) <- c("Cy3","Cy5")
      exprSetArrayObject <- new("exprSetArray", 	
	exprs=as.matrix(cbind(Xr1,Xr2)), phenoData=	
          new("phenoData", pData=data.frame(matrix(0,nrow=4,ncol=1)),
              varLabels=list(rep("varLabel1",1))), channels=channels)		


      Re3 <- qualityParameters(arrayDataObject=arrayDataObject, exprSetArrayObject=exprSetArrayObject, identifiersToBeSkipped= "Blank")

      stopifnot(all.equal.numeric(as.numeric(Re3$qualityParameters["H2",c("correlation")]),c(1)))
      stopifnot(Re3$replicateSpots==3)
   }

	}

 \keyword{}

 \author{Andreas Buness <a.buness@dkfz.de>}
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% End of File
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
